-----------------------------------------------------------------------------------------------
-- Client Lua Script for WillYouBeMyNeighbor
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
require "HousingLib"
 
-----------------------------------------------------------------------------------------------
-- WillYouBeMyNeighbor Module Definition
-----------------------------------------------------------------------------------------------

WillYouBeMyNeighbor = {} 
WillYouBeMyNeighbor.tLocale = {}
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
local version = 1.047

local kcrOnline = ApolloColor.new("UI_TextHoloBodyHighlight")
local kcrOffline = ApolloColor.new("UI_BtnTextGrayNormal") 
local RegisteredUsers = {}
local OnlineUsers = {}
local AutoDisplay = true
local AutoAccept = false
local DeclineByFilter = false
local NodeFilter = "Mineral Deposit"
local ShareFilter = 0
local NodeLevelFilter = 1
local GuildFilter = ""
local PlantPiratesAlert = true
local HarvestNotifications = true
local AcceptAllSocials = false

local Plugs = {}

-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------

function WillYouBeMyNeighbor:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self

    -- initialize variables here

    return o
end

function WillYouBeMyNeighbor:Init()
    local bHasConfigureFunction = false
    local strConfigureButtonText = ""
    local tDependencies = {
        "NeighborList"
    }
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 
-----------------------------------------------------------------------------------------------
-- Saved Information
-----------------------------------------------------------------------------------------------

function WillYouBeMyNeighbor:OnSave(eLevel)
    if eLevel ~= GameLib.CodeEnumAddonSaveLevel.Character then
        return nil
    end
    
    local save = {}
    save.AutoDisplay = AutoDisplay
	save.AutoAccept = AutoAccept
	save.DeclineByFilter = DeclineByFilter
	save.NodeFilter = NodeFilter
	save.ShareFilter = ShareFilter
	save.NodeLevelFilter = NodeLevelFilter
	save.GuildFilter = GuildFilter
	save.PlantPiratesAlert = PlantPiratesAlert
    save.HarvestNotifications = HarvestNotifications 
	save.AcceptAllSocials = AcceptAllSocials 
    save.RegisteredUsers = RegisteredUsers
    return save 
end

function WillYouBeMyNeighbor:OnRestore(eLevel, tData)
    if eLevel == GameLib.CodeEnumAddonSaveLevel.Character then
        if tData.AutoDisplay  ~= nil then AutoDisplay = tData.AutoDisplay end
		if tData.AutoAccept  ~= nil then AutoAccept = tData.AutoAccept end
		if tData.DeclineByFilter ~= nil then DeclineByFilter = tData.DeclineByFilter end
		if tData.NodeFilter  ~= nil then NodeFilter = tData.NodeFilter end
		if tData.ShareFilter ~= nil then ShareFilter = tData.ShareFilter end
		if tData.NodeLevelFilter  ~= nil then NodeLevelFilter = tData.NodeLevelFilter end
		if tData.GuildFilter ~= nil then GuildFilter = tData.GuildFilter end
		if tData.PlantPiratesAlert ~= nil then PlantPiratesAlert = tData.PlantPiratesAlert end
		if tData.HarvestNotifications ~= nil then HarvestNotifications = tData.HarvestNotifications end
		if tData.AcceptAllSocials ~= nil then AcceptAllSocials = tData.AcceptAllSocials end
        if tData.RegisteredUsers  ~= nil then RegisteredUsers = tData.RegisteredUsers end
	end
end

-----------------------------------------------------------------------------------------------
-- OnLoad
-----------------------------------------------------------------------------------------------

function WillYouBeMyNeighbor:OnLoad()
    -- load our form file
    self.xmlDoc = XmlDoc.CreateFromFile("WillYouBeMyNeighbor.xml")
    self.xmlDoc:RegisterCallback("OnDocLoaded", self)

	if Apollo.GetAddon("VikingContextMenuPlayer") ~= nil then
	    self.contextMenuPlayer = Apollo.GetAddon("VikingContextMenuPlayer")
	else
	    self.contextMenuPlayer = Apollo.GetAddon("ContextMenuPlayer")
	end
    local oldRedrawAll = self.contextMenuPlayer.RedrawAll

    self.contextMenuPlayer.RedrawAll = function(context)
        if self.contextMenuPlayer.wndMain ~= nil then
            local wndButtonList = self.contextMenuPlayer.wndMain:FindChild("ButtonList")
            if wndButtonList ~= nil then
                local wndNew = wndButtonList:FindChildByUserData(tObject)
                if not wndNew then
                    wndNew = Apollo.LoadForm(self.contextMenuPlayer.xmlDoc, "BtnRegular", wndButtonList, self.contextMenuPlayer)
                    wndNew:SetData("VisitNeighbor")
                end
                wndNew:FindChild("BtnText"):SetText("Visit Neighbor")
            end
        end
        oldRedrawAll(context)
    end

    -- catch the event fired when the player clicks the context menu
    local oldProcessContextClick = self.contextMenuPlayer.ProcessContextClick
    self.contextMenuPlayer.ProcessContextClick = function(context, eButtonType)
        if eButtonType == "VisitNeighbor" then
            self:VisitNeighbor(self.contextMenuPlayer.strTarget)
        else
            oldProcessContextClick (context, eButtonType)
        end
    end

	self.tQueuedUnits = {}
	self.rosters = {}
	
	Apollo.RegisterEventHandler("UnitCreated", "OnUnitCreated", self)
	Apollo.RegisterEventHandler("InterfaceMenuListHasLoaded", "OnInterfaceMenuListHasLoaded", self)
	Apollo.RegisterEventHandler("HarvestItemsSentToOwner", "OnHarvest", self)

    self.chanICC = ICCommLib.JoinChannel("WillYouBeMyNeighborChannel", "OnDotMessageWillYouBeMyNeighborChannelMessage", self)
    self.chanICCOL = ICCommLib.JoinChannel("WillYouBeMyNeighborOnlineChannel", "OnDotMessageWillYouBeMyNeighborOnlineChannelMessage", self)
    self.chanICCPP = ICCommLib.JoinChannel("WillYouBeMyNeighborPPChannel", "OnDotMessageWillYouBeMyNeighborPPChannelMessage", self)
    self.chanICCHN = ICCommLib.JoinChannel("WillYouBeMyNeighborHarvestNotificationChannel", "OnDotMessageWillYouBeMyNeighborHarvestNotificationChannelMessage", self)
	self:SetLocaleData()
end

-----------------------------------------------------------------------------------------------
-- OnDocLoaded
-----------------------------------------------------------------------------------------------

function WillYouBeMyNeighbor:OnDocLoaded()
    if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
        self.wndMain = Apollo.LoadForm(self.xmlDoc, "WillYouBeMyNeighborForm", nil, self)
        if self.wndMain == nil then
            Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
            return
        end
        
        self.wndMain:Show(false, true)

        -- if the xmlDoc is no longer needed, you should set it to nil
        -- self.xmlDoc = nil
        
        -- Register handlers for events, slash commands and timer, etc.
        -- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
        Apollo.RegisterSlashCommand("rogers", "OnWillYouBeMyNeighborOn", self)
		Apollo.RegisterEventHandler("WillYouBeMyNeighborOn", "OnWillYouBeMyNeighborOn", self)
        Apollo.RegisterEventHandler("GuildRoster", "OnGuildRoster", self)
        Apollo.RegisterEventHandler("ZoneCompletionUpdated",    "OnZoneCompletionUpdated",  self)
		Apollo.RegisterEventHandler("HousingNeighborInviteRecieved", 	"OnNeighborInviteRecieved", self)
		Apollo.RegisterEventHandler("WindowManagementReady", "OnWindowManagementReady", self)
        -- Do additional Addon initialization here
        
        self.currentNeighbor = 1
		self.currentNeighborName = ""
        self.expanded = false
        self.performInvites = ""  
		self.faction = 0
		
		self.timer = ApolloTimer.Create(5.0, true, "UpdateMyself", self)
    	self.timer1 = ApolloTimer.Create(1.0, true, "UpdateCurrent", self)

        self.wndMain:FindChild("ComboShareRatioList"):AddItem("100% to me", "", "100% to me")
        self.wndMain:FindChild("ComboShareRatioList"):AddItem("75% to me", "", "75% to me")
        self.wndMain:FindChild("ComboShareRatioList"):AddItem("50% to me", "", "50% to me")
        self.wndMain:FindChild("ComboShareRatioList"):AddItem("25% to me", "", "25% to me")
        self.wndMain:FindChild("ComboShareRatioList"):AddItem("0% to me", "", "0% to me")
        self:PopulateCircles()

    end
end


-----------------------------------------------------------------------------------------------
-- WillYouBeMyNeighbor Functions
-----------------------------------------------------------------------------------------------

function WillYouBeMyNeighbor:OnHarvest(data)
	local name = GameLib.GetPlayerUnit():GetName()
	local onplot = self.wndMain:FindChild("WillYouBeMyNeighborCurrentName"):GetText()
	if RegisteredUsers[name] == nil then return end
	if type(RegisteredUsers[name]) ~= "table" then return end
	if RegisteredUsers[name].activity == nil then
		RegisteredUsers[name].activity = 0
	end
	if RegisteredUsers[name].month ~= GameLib:GetServerTime().nMonth then
		RegisteredUsers[name].month = GameLib:GetServerTime().nMonth
		RegisteredUsers[name].activity = 0
	end
	
	for _, val in pairs(data) do
		RegisteredUsers[name].activity = RegisteredUsers[name].activity + val.nCount
		if val.item:GetItemCategory() == 104 then
			local t = {}
            t.name = onplot
            t.message = "PLANT PIRATE ALERT: " .. name .. " harvested " .. val.item:GetName() .. " from your plot"
            self.chanICCPP:SendMessage(t)
		else
			local t = {}
            t.name = onplot
            t.message = name .. " harvested " .. val.nCount .. " " .. val.item:GetName() .. " for you!"
            self.chanICCHN:SendMessage(t)
		end
	end
	
end

function WillYouBeMyNeighbor:OnInterfaceMenuListHasLoaded()
	
	Event_FireGenericEvent("InterfaceMenuList_NewAddOn", "WillYouBeMyNeighbor", {"WillYouBeMyNeighborOn", "", "BK3:sprHolo_Friends_Account"})

end

function WillYouBeMyNeighbor:OnDotMessageWillYouBeMyNeighborChannelMessage(channel, tMsg)
	self.unitPlayerDisposition = GameLib.GetPlayerUnit()
	if self.unitPlayerDisposition == nil or not self.unitPlayerDisposition:IsValid() or RegisteredUsers == nil then
		self.tQueuedUnits = {}
		return
	end	
	if GameLib.GetPlayerUnit():GetName() == tMsg.name then return end
	
	if RegisteredUsers[tMsg.name] ~= nil and type(RegisteredUsers[tMsg.name]) == "table" then
		if RegisteredUsers[tMsg.name].share ~= nil and tMsg.share == nil then return end
		if RegisteredUsers[tMsg.name].nodetype ~= nil and tMsg.nodetype == nil then return end
		if RegisteredUsers[tMsg.name].faction ~= nil and tMsg.faction == nil then return end
		if RegisteredUsers[tMsg.name].remaining ~= nil and tMsg.remaining == nil then return end
		if RegisteredUsers[tMsg.name].timestamp ~= nil and tMsg.timestamp == nil then return end
		if RegisteredUsers[tMsg.name].month ~= nil and tMsg.month == nil then return end
		if RegisteredUsers[tMsg.name].activity ~= nil and tMsg.activity == nil then return end
		if RegisteredUsers[tMsg.name].version ~= nil and tMsg.version == nil then return end
		
		if RegisteredUsers[tMsg.name].version ~= nil and tMsg.senderversion ~= nil and RegisteredUsers[tMsg.name].version > tMsg.senderversion then return end
		
		if tMsg.timestamp == nil or (RegisteredUsers[tMsg.name].timestamp ~= nil and RegisteredUsers[tMsg.name].timestamp > tMsg.timestamp) then return end
		
		if type(RegisteredUsers[tMsg.name].share) == "table" then
			RegisteredUsers[tMsg.name] = nil
		end
	end
	
	if tMsg.nodetype == nil then
		if type(RegisteredUsers[tMsg.name]) == "table" then 
			return
		end
		if type(tMsg.share) == "table" then return end
		RegisteredUsers[tMsg.name] = tMsg.share
	else
		if tMsg.version ~= nil and tMsg.version > version then
			self.wndMain:FindChild("VersionUpdate"):Show(true)
		end
	    RegisteredUsers[tMsg.name] = tMsg
		end
end

function WillYouBeMyNeighbor:OnDotMessageWillYouBeMyNeighborPPChannelMessage(channel, tMsg)
	self.unitPlayerDisposition = GameLib.GetPlayerUnit()
	if self.unitPlayerDisposition == nil or not self.unitPlayerDisposition:IsValid() or RegisteredUsers == nil then
		self.tQueuedUnits = {}
		return
	end	
	local name = GameLib.GetPlayerUnit():GetName()
	
	if PlantPiratesAlert == true and tMsg.name == name then
	    ChatSystemLib.PostOnChannel(2, tMsg.message)
	end
end

function WillYouBeMyNeighbor:OnDotMessageWillYouBeMyNeighborHarvestNotificationChannelMessage(channel, tMsg)
	self.unitPlayerDisposition = GameLib.GetPlayerUnit()
	if self.unitPlayerDisposition == nil or not self.unitPlayerDisposition:IsValid() or RegisteredUsers == nil then
		self.tQueuedUnits = {}
		return
	end	
	local name = GameLib.GetPlayerUnit():GetName()
	
	if HarvestNotifications == true and tMsg.name == name then
	    ChatSystemLib.PostOnChannel(8, tMsg.message)
	end
end

function WillYouBeMyNeighbor:OnDotMessageWillYouBeMyNeighborOnlineChannelMessage(channel, tMsg)
	self.unitPlayerDisposition = GameLib.GetPlayerUnit()
	if self.unitPlayerDisposition == nil or not self.unitPlayerDisposition:IsValid() or OnlineUsers == nil then
		self.tQueuedUnits = {}
		return
	end	
	OnlineUsers[tMsg.name] = self.ServerTime()
end
function WillYouBeMyNeighbor:VisitNeighbor(Name)
    if HousingLib.IsHousingWorld() == false then
        ChatSystemLib.PostOnChannel(2,"You can't visit people if you're not in the housing system!")
        return
    end

    local neighborList=HousingLib.GetNeighborList()
    for i=1,#neighborList do
        if neighborList[i].strCharacterName == Name then
            HousingLib.VisitNeighborResidence(neighborList[i].nId)
            return
        end
    end
    ChatSystemLib.PostOnChannel(2,Name .. " is not a neighbor, sending neighbor invite!")
    HousingLib.NeighborInviteByName(Name)
end

local shares = { "100%", "75%", "50%", "25%", "0%" }

function WillYouBeMyNeighbor:UpdateTargetPlot(name)
    self.wndMain:FindChild("WillYouBeMyNeighborName"):SetText(name)

    local neighborList=HousingLib.GetNeighborList()
	local neighborIndex = 0
	for i=1, #neighborList do
	    if neighborList[i].strCharacterName == name then	
			neighborIndex = i
			break
	    end
	end
    if RegisteredUsers[name] ~= nil then
		local val = RegisteredUsers[name]
		if type(val) == "number" then
	        self.wndMain:FindChild("WillYouBeMyNeighborShare"):SetText(string.format("%s to Owner", shares[val + 1]))
			self.wndMain:FindChild("WillYouBeMyNeighborNodeInfo"):SetText("Unknown")
			self.wndMain:FindChild("WillYouBeMyNeighborHarvestInfo"):SetText("Unknown")
			self.wndMain:FindChild("WillYouBeMyNeighborRemaining"):SetText("Unknown")
			self.wndMain:FindChild("WillYouBeMyNeighborActivity"):SetText("Unknown")
			self.wndMain:FindChild("WillYouBeMyNeighborVersionFlag"):Show(false)
	        return
		end
		if type(val) == "table" then
			if type(val.share) == "table" then return end
	        self.wndMain:FindChild("WillYouBeMyNeighborShare"):SetText(string.format("%s to Owner", shares[val.share + 1]))
				if val.nodetype == nil then
					self.wndMain:FindChild("WillYouBeMyNeighborNodeInfo"):SetText("Unknown")
				elseif val.nodelevel ~= nil then
					self.wndMain:FindChild("WillYouBeMyNeighborNodeInfo"):SetText(val.nodetype .. " " .. val.nodelevel)
				else
					self.wndMain:FindChild("WillYouBeMyNeighborNodeInfo"):SetText(val.nodetype)
				end
			local harvest
			if val.miner == true then
				harvest = "Miner"
			end
			if val.survivalist == true then
				if harvest == "Miner" then
					harvest = "Miner/Survivalist"
				else
					harvest = "Survivalist"
				end
			end
			if val.relichunter == true then
				if harvest == "Miner" or harvest == "Survivalist" then
					harvest = harvest .. "/Relic Hunter"
				else
					harvest = "Relic Hunter"
				end
			end
			self.wndMain:FindChild("WillYouBeMyNeighborHarvestInfo"):SetText(harvest)
			if neighborList[neighborIndex] == nil or neighborList[neighborIndex].fLastOnline == nil then
				self.wndMain:FindChild("WillYouBeMyNeighborCurrentRemaining"):SetText("Unknown")				
			else
				self.wndMain:FindChild("WillYouBeMyNeighborRemaining"):SetText(self:HelperConvertToTime(neighborList[neighborIndex].fLastOnline))			
			end
			if val.activity ~= nil then
				if val.month ~= nil and val.month == GameLib:GetServerTime().nMonth then
					self.wndMain:FindChild("WillYouBeMyNeighborActivity"):SetText(val.activity .. " units")
				else
					self.wndMain:FindChild("WillYouBeMyNeighborActivity"):SetText("0 units")
				end
			else
				self.wndMain:FindChild("WillYouBeMyNeighborActivity"):SetText("Unknown")
			end
			if val.version == nil or val.version < version then
				self.wndMain:FindChild("WillYouBeMyNeighborVersionFlag"):Show(false)
			else
				self.wndMain:FindChild("WillYouBeMyNeighborVersionFlag"):Show(true)
			end
	        return
		end
    end
    self.wndMain:FindChild("WillYouBeMyNeighborShare"):SetText("Unknown")
	self.wndMain:FindChild("WillYouBeMyNeighborNodeInfo"):SetText("Unknown")
	self.wndMain:FindChild("WillYouBeMyNeighborHarvestInfo"):SetText("Unknown")
	self.wndMain:FindChild("WillYouBeMyNeighborRemaining"):SetText("Unknown")
	self.wndMain:FindChild("WillYouBeMyNeighborActivity"):SetText("Unknown")
	self.wndMain:FindChild("WillYouBeMyNeighborVersionFlag"):Show(false)
end

-- on SlashCommand "/rogers"
function WillYouBeMyNeighbor:OnWillYouBeMyNeighborOn(cmd, args)
    local neighborList=HousingLib.GetNeighborList()
    if self.currentNeighbor > #neighborList then
        self.currentNeighbor = 1
    end

	if args == "visit" then
		self:OnVisit()
		return
	end

    self.wndMain:Invoke() -- show the window
	if #neighborList == 0 then
		self.wndMain:FindChild("WillYouBeMyNeighborName"):SetText("No Neighbors")
		self.wndMain:FindChild("WillYouBeMyNeighborShare"):SetText("Unknown")
		self.wndMain:FindChild("WillYouBeMyNeighborNodeInfo"):SetText("Unknown")
		self.wndMain:FindChild("WillYouBeMyNeighborHarvestInfo"):SetText("Unknown")
		self.wndMain:FindChild("WillYouBeMyNeighborRemaining"):SetText("Unknown")
		self.wndMain:FindChild("WillYouBeMyNeighborActivity"):SetText("Unknown")
		self.wndMain:FindChild("WillYouBeMyNeighborVersionFlag"):Show(false)		
	else
		self.currentNeighborName = neighborList[self.currentNeighbor].strCharacterName
	    self:UpdateTargetPlot(neighborList[self.currentNeighbor].strCharacterName);
	    if neighborList[self.currentNeighbor].fLastOnline == 0 then
	        self.wndMain:FindChild("WillYouBeMyNeighborName"):SetTextColor(kcrOnline)
	    else
	        self.wndMain:FindChild("WillYouBeMyNeighborName"):SetTextColor(kcrOffline)
	    end 
	end

    self.wndMain:FindChild("AutoDisplay"):SetCheck(AutoDisplay)
	self.wndMain:FindChild("AutoAccept"):SetCheck(AutoAccept)
	if NodeFilter == "Mineral Deposit" then self.wndMain:FindChild("RadioMineral"):SetCheck(true) end
	if NodeFilter == "Thicket" then self.wndMain:FindChild("RadioThicket"):SetCheck(true) end
	if NodeFilter == "Relic Excavation" then self.wndMain:FindChild("RadioRelic"):SetCheck(true) end
	if NodeLevelFilter == 1 then self.wndMain:FindChild("RadioLevel1"):SetCheck(true) end
	if NodeLevelFilter == 2 then self.wndMain:FindChild("RadioLevel2"):SetCheck(true) end
	if NodeLevelFilter == 3 then self.wndMain:FindChild("RadioLevel3"):SetCheck(true) end
	if NodeLevelFilter == 4 then self.wndMain:FindChild("RadioLevel4"):SetCheck(true) end
	if ShareFilter == 0 then self.wndMain:FindChild("RadioShare100"):SetCheck(true) end
	if ShareFilter == 1 then self.wndMain:FindChild("RadioShare75"):SetCheck(true) end
	if ShareFilter == 2 then self.wndMain:FindChild("RadioShare50"):SetCheck(true) end
	if ShareFilter == 3 then self.wndMain:FindChild("RadioShare25"):SetCheck(true) end
	if ShareFilter == 4 then self.wndMain:FindChild("RadioShare0"):SetCheck(true) end
	self.wndMain:FindChild("ComboCircleList"):SetText(GuildFilter);
	self.wndMain:FindChild("AutoAcceptGridFilter"):SetCheck(DeclineByFilter)
	self.wndMain:FindChild("PlantPiratesAlert"):SetCheck(PlantPiratesAlert)
	self.wndMain:FindChild("HarvestNotifications"):SetCheck(HarvestNotifications)
	self.wndMain:FindChild("AcceptAllSocials"):SetCheck(AcceptAllSocials)
	end

function WillYouBeMyNeighbor:PopulateCircles()
    self.wndMain:FindChild("ComboCircleList")
    local guilds = GuildLib.GetGuilds()
    self.wndMain:FindChild("ComboCircleList"):AddItem("", "", "")
    for i, guild in pairs(guilds) do
        self.wndMain:FindChild("ComboCircleList"):AddItem(guild:GetName(), "", guild:GetName())
    end
end

function WillYouBeMyNeighbor:OnGuildRoster(uGuild, tRoster)
	self.rosters[uGuild:GetName()] = tRoster
end

function WillYouBeMyNeighbor:OnZoneCompletionUpdated()
	if self.unitPlayerDisposition == nill or not self.unitPlayerDisposition:IsValid() or RegisteredUsers == nil then
		self.tQueuedUnits = {}
		return
	end	
	self:BuildSocialWorld()
	
    if HousingLib:IsHousingWorld() == true then
        if AutoDisplay == true then
            self.wndMain:Invoke() -- show the window
            local neighborList=HousingLib.GetNeighborList()
            if self.currentNeighbor > #neighborList then
                self.currentNeighbor = 1
            end
			if #neighborList == 0 then
				self.wndMain:FindChild("WillYouBeMyNeighborName"):SetText("No Neighbors")
				self.wndMain:FindChild("WillYouBeMyNeighborShare"):SetText("Unknown")
				self.wndMain:FindChild("WillYouBeMyNeighborNodeInfo"):SetText("Unknown")
				self.wndMain:FindChild("WillYouBeMyNeighborHarvestInfo"):SetText("Unknown")
				self.wndMain:FindChild("WillYouBeMyNeighborRemaining"):SetText("Unknown")
				self.wndMain:FindChild("WillYouBeMyNeighborActivity"):SetText("Unknown")
				self.wndMain:FindChild("WillYouBeMyNeighborVersionFlag"):Show(false)		
			else
				self.currentNeighborName = neighborList[self.currentNeighbor].strCharacterName
			    self:UpdateTargetPlot(neighborList[self.currentNeighbor].strCharacterName);
			    if neighborList[self.currentNeighbor].fLastOnline == 0 then
			        self.wndMain:FindChild("WillYouBeMyNeighborName"):SetTextColor(kcrOnline)
			    else
			        self.wndMain:FindChild("WillYouBeMyNeighborName"):SetTextColor(kcrOffline)
			    end 
			end
            self.wndMain:FindChild("AutoDisplay"):SetCheck(AutoDisplay)
			self.wndMain:FindChild("AutoAccept"):SetCheck(AutoAccept)
			if NodeFilter == "Mineral Deposit" then self.wndMain:FindChild("RadioMineral"):SetCheck(true) end
			if NodeFilter == "Thicket" then self.wndMain:FindChild("RadioThicket"):SetCheck(true) end
			if NodeFilter == "Relic Excavation" then self.wndMain:FindChild("RadioRelic"):SetCheck(true) end
			if NodeLevelFilter == 1 then self.wndMain:FindChild("RadioLevel1"):SetCheck(true) end
			if NodeLevelFilter == 2 then self.wndMain:FindChild("RadioLevel2"):SetCheck(true) end
			if NodeLevelFilter == 3 then self.wndMain:FindChild("RadioLevel3"):SetCheck(true) end
			if NodeLevelFilter == 4 then self.wndMain:FindChild("RadioLevel4"):SetCheck(true) end
			if ShareFilter == 0 then self.wndMain:FindChild("RadioShare100"):SetCheck(true) end
			if ShareFilter == 1 then self.wndMain:FindChild("RadioShare75"):SetCheck(true) end
			if ShareFilter == 2 then self.wndMain:FindChild("RadioShare50"):SetCheck(true) end
			if ShareFilter == 3 then self.wndMain:FindChild("RadioShare25"):SetCheck(true) end
			if ShareFilter == 4 then self.wndMain:FindChild("RadioShare0"):SetCheck(true) end
			self.wndMain:FindChild("ComboCircleList"):SetText(GuildFilter);
			self.wndMain:FindChild("AutoAcceptGridFilter"):SetCheck(DeclineByFilter)
			self.wndMain:FindChild("PlantPiratesAlert"):SetCheck(PlantPiratesAlert)
			self.wndMain:FindChild("HarvestNotifications"):SetCheck(HarvestNotifications)
			self.wndMain:FindChild("AcceptAllSocials"):SetCheck(AcceptAllSocials)
		end
    else
        if AutoDisplay == true then
            self.wndMain:Close()
        end
    end 
end

local currentBroadcast = ""

function WillYouBeMyNeighbor:UpdateCurrent()
	self.unitPlayerDisposition = GameLib.GetPlayerUnit()
	if self.unitPlayerDisposition == nil or not self.unitPlayerDisposition:IsValid() or RegisteredUsers == nil or GetCurrentZoneName() == nil then
		self.tQueuedUnits = {}
		return
	end	
	
	if HousingLib:IsHousingWorld() == true and HousingLib:IsWarplotResidence() == false then
		local name = n
		
		if HousingLib:IsOnMyResidence() == true then
			name = GameLib.GetPlayerUnit():GetName()
		else
			name = string.match(GetCurrentZoneName(), "%b[]")
			name = name:sub(2, -2)
		end
	    self.wndMain:FindChild("WillYouBeMyNeighborCurrentName"):SetText(name)
	
		local neighborIndex = 0
	    local neighborList=HousingLib.GetNeighborList()
		for i=1, #neighborList do
		    if neighborList[i].strCharacterName == name then
			    if neighborList[i].fLastOnline == 0 then
			        self.wndMain:FindChild("WillYouBeMyNeighborCurrentName"):SetTextColor(kcrOnline)
			    else
			        self.wndMain:FindChild("WillYouBeMyNeighborCurrentName"):SetTextColor(kcrOffline)
			    end				
				neighborIndex = i
				break
		    end
		end

	    if RegisteredUsers[name] ~= nil then
			local val = RegisteredUsers[name]
			if type(val) == "number" then
		        self.wndMain:FindChild("WillYouBeMyNeighborCurrentShare"):SetText(string.format("%s to Owner", shares[val + 1]))
				self.wndMain:FindChild("WillYouBeMyNeighborCurrentNodeInfo"):SetText("Unknown")
				self.wndMain:FindChild("WillYouBeMyNeighborCurrentHarvestInfo"):SetText("Unknown")
				self.wndMain:FindChild("WillYouBeMyNeighborCurrentRemaining"):SetText("Unknown")
				self.wndMain:FindChild("WillYouBeMyNeighborCurrentActivity"):SetText("Unknown")
				self.wndMain:FindChild("WillYouBeMyNeighborCurrentVersionFlag"):Show(false)
		        return
			end
			if type(val) == "table" then
				if type(val.share) == "table" then return end
		        self.wndMain:FindChild("WillYouBeMyNeighborCurrentShare"):SetText(string.format("%s to Owner", shares[val.share + 1]))
				if val.nodetype == nil then
					self.wndMain:FindChild("WillYouBeMyNeighborCurrentNodeInfo"):SetText("Unknown")
				elseif val.nodelevel ~= nil then
					self.wndMain:FindChild("WillYouBeMyNeighborCurrentNodeInfo"):SetText(val.nodetype .. " " .. val.nodelevel)
				else
					self.wndMain:FindChild("WillYouBeMyNeighborCurrentNodeInfo"):SetText(val.nodetype)
				end
				local harvest = ""
				if val.miner == true then
					harvest = "Miner"
				end
				if val.survivalist == true then
					if harvest == "Miner" then
						harvest = "Miner/Survivalist"
					else
						harvest = "Survivalist"
					end
				end
				if val.relichunter == true then
					if harvest == "Miner" or harvest == "Survivalist" then
						harvest = harvest .. "/Relic Hunter"
					else
						harvest = "Relic Hunter"
					end
				end
				self.wndMain:FindChild("WillYouBeMyNeighborCurrentHarvestInfo"):SetText(harvest)
				if GameLib:GetPlayerUnit():GetName() == name then
					self.wndMain:FindChild("WillYouBeMyNeighborCurrentRemaining"):SetText("Online")
				elseif neighborList[neighborIndex] == nil or neighborList[neighborIndex].fLastOnline == nil then
					self.wndMain:FindChild("WillYouBeMyNeighborCurrentRemaining"):SetText("Unknown")				
				else
					self.wndMain:FindChild("WillYouBeMyNeighborRemaining"):SetText(self:HelperConvertToTime(neighborList[neighborIndex].fLastOnline))			
				end					
				if val.activity ~= nil then
					if val.month ~= nil and val.month == GameLib:GetServerTime().nMonth then
						self.wndMain:FindChild("WillYouBeMyNeighborCurrentActivity"):SetText(val.activity .. " units")
					else
						self.wndMain:FindChild("WillYouBeMyNeighborCurrentActivity"):SetText("0 units")
					end
				else
					self.wndMain:FindChild("WillYouBeMyNeighborCurrentActivity"):SetText("Unknown")
				end
				if val.version == nil or val.version < version then
					self.wndMain:FindChild("WillYouBeMyNeighborCurrentVersionFlag"):Show(false)
				else
					self.wndMain:FindChild("WillYouBeMyNeighborCurrentVersionFlag"):Show(true)
				end
		        return
			end
	    end
	    self.wndMain:FindChild("WillYouBeMyNeighborCurrentShare"):SetText("Unknown")
		self.wndMain:FindChild("WillYouBeMyNeighborCurrentNodeInfo"):SetText("Unknown")
		self.wndMain:FindChild("WillYouBeMyNeighborCurrentHarvestInfo"):SetText("Unknown")
		self.wndMain:FindChild("WillYouBeMyNeighborCurrentRemaining"):SetText("Unknown")
		self.wndMain:FindChild("WillYouBeMyNeighborCurrentActivity"):SetText("Unknown")
		self.wndMain:FindChild("WillYouBeMyNeighborCurrentVersionFlag"):Show(false)
	else
		self.wndMain:FindChild("WillYouBeMyNeighborCurrentName"):SetText("Unknown")
		self.wndMain:FindChild("WillYouBeMyNeighborCurrentShare"):SetText("Unknown")
		self.wndMain:FindChild("WillYouBeMyNeighborCurrentNodeInfo"):SetText("Unknown")
		self.wndMain:FindChild("WillYouBeMyNeighborCurrentHarvestInfo"):SetText("Unknown")
		self.wndMain:FindChild("WillYouBeMyNeighborCurrentRemaining"):SetText("Unknown")
		self.wndMain:FindChild("WillYouBeMyNeighborCurrentActivity"):SetText("Unknown")
		self.wndMain:FindChild("WillYouBeMyNeighborCurrentVersionFlag"):Show(false)
	end
end

function WillYouBeMyNeighbor:UpdateMyself()
	self.unitPlayerDisposition = GameLib.GetPlayerUnit()
	if self.unitPlayerDisposition == nil or not self.unitPlayerDisposition:IsValid() or RegisteredUsers == nil then
		self.tQueuedUnits = {}
		return
	end	
	
    local neighborList=HousingLib.GetNeighborList()
	if #neighborList < 100 then
		local online = {}
		online.name = GameLib.GetPlayerUnit():GetName()
	    self.chanICCOL:SendMessage(online)
	end

	self.faction = GameLib.GetPlayerUnit():GetFaction()

	local aNeighborList = Apollo.GetAddon("NeighborList")
	Apollo.RemoveEventHandler("HousingNeighborInviteRecieved", aNeighborList)
	
    if HousingLib:IsHousingWorld() == true and HousingLib:IsOnMyResidence() == true then
        local t = {}
        name = GameLib.GetPlayerUnit():GetName()
		if RegisteredUsers[name] == nil then RegisteredUsers[name] = {} end
		RegisteredUsers[name].name = name
        RegisteredUsers[name].share = HousingLib:GetNeighborHarvestSplit()
		RegisteredUsers[name].nodetype = "No Node"
		RegisteredUsers[name].remaining = 0

		for i=1, 6 do
			local cPlot = HousingLib.GetPlot(i)
			for _, tNode in ipairs(Plugs) do
				if tNode == cPlot.strName then
					RegisteredUsers[name].nodetype = cPlot.strName
					RegisteredUsers[name].remaining = cPlot.fRemainingHours
				end
			end
		end
		
		RegisteredUsers[name].relichunter = false
		RegisteredUsers[name].survivalist = false
		RegisteredUsers[name].miner = false

		local tKnownSkills = CraftingLib.GetKnownTradeskills()
		if tKnownSkills then
			for nIndex, tSkill in ipairs(tKnownSkills) do
				local tInfo = CraftingLib.GetTradeskillInfo(tSkill.eId)
				if tInfo and tInfo.bIsActive then
					if tSkill.strName == "Relic Hunter" then
						RegisteredUsers[name].relichunter = true
					elseif tSkill.strName == "Survivalist" then
						RegisteredUsers[name].survivalist = true
					elseif tSkill.strName == "Mining" then
						RegisteredUsers[name].miner = true
					end
				end
			end
		end
		RegisteredUsers[name].timestamp = self.ServerTime()
		RegisteredUsers[name].faction = GameLib.GetPlayerUnit():GetFaction()
		RegisteredUsers[name].version = version
		
		RegisteredUsers[name].nodelevel = nil
		
		if RegisteredUsers[name].day ~= GameLib:GetServerTime().nDay then
			RegisteredUsers[name].day = GameLib:GetServerTime().nDay
		end
			
		self.chanICC:SendMessage(RegisteredUsers[name])
	else
		self.tQueuedUnits = {}
	end	  
	
	
	if currentBroadcast == "" then
		currentBroadcast = next(RegisteredUsers)
		if RegisteredUsers[currentBroadcast] == nil then return end
		local val = RegisteredUsers[currentBroadcast]
        local t = {}			
		if type(val) == "number" then
            t.name = currentBroadcast
            t.share = RegisteredUsers[currentBroadcast]
            self.chanICC:SendMessage(t)
	        return
		end
		if type(val) == "table" then
			local subtable = RegisteredUsers[currentBroadcast].share
			if type(subtable) == "table" then return end
			if RegisteredUsers[currentBroadcast].name == nil then RegisteredUsers[currentBroadcast].name = currentBroadcast end
	        self.chanICC:SendMessage(RegisteredUsers[currentBroadcast])
	        return
		end		
	else
		if RegisteredUsers[currentBroadcast] == nil then return end
		currentBroadcast = next(RegisteredUsers, currentBroadcast)
		if currentBroadcast == nil then currentBroadcast = next(RegisteredUsers) end
		local val = RegisteredUsers[currentBroadcast]
        local t = {}			
		if type(val) == "number" then
            t.name = currentBroadcast
            t.share = RegisteredUsers[currentBroadcast]
            self.chanICC:SendMessage(t)
	        return
		end
		if type(val) == "table" then
			local subtable = RegisteredUsers[currentBroadcast].share
			if type(subtable) == "table" then return end
			if RegisteredUsers[currentBroadcast].name == nil then RegisteredUsers[currentBroadcast].name = currentBroadcast end
	        self.chanICC:SendMessage(RegisteredUsers[currentBroadcast])
	        return
		end		
	end	
end

function WillYouBeMyNeighbor:OnUnitCreated(unit)
	if HousingLib.IsHousingWorld() == false then
		return
	end
	if unit == null or not unit:IsValid() or unit == GameLib.GetPlayerUnit() then
		return
	end
	table.insert(self.tQueuedUnits, unit)
end

function WillYouBeMyNeighbor:OnNeighborInviteRecieved(strName)
	local aNeighborList = Apollo.GetAddon("NeighborList")
	if AutoAccept == true then
		if DeclineByFilter == false then
			aNeighborList.strInviterName = strName	
			HousingLib.NeighborInviteAccept()
			ChatSystemLib.PostOnChannel(2,"Invite from " .. strName .. " accepted by WillYouBeMyNeighbor")
		elseif RegisteredUsers[strName] ~= nil then
			local key = strName
			local val = RegisteredUsers[key]
			
			if AcceptAllSocials == true and self.rosters ~= nil then
				for _, groupMember in pairs(self.rosters[GuildFilter]) do
					if groupMember.strName == key then
						HousingLib.NeighborInviteAccept()
						ChatSystemLib.PostOnChannel(2,"Invite from " .. strName .. " accepted by WillYouBeMyNeighbor")
						return					
					end
				end			
			end
			if GuildFilter ~= nil and GuildFilter ~= "" and self.rosters[GuildFilter] ~= nil then
				for _, groupMember in pairs(self.rosters[GuildFilter]) do
					if groupMember.strName == key then
						if type(val) == "table" and type(val.share) ~= "table" and key ~= GameLib:GetPlayerUnit():GetName() and val.share >= ShareFilter then
							if val.remaining ~= nil and val.faction == self.faction and string.find(val.nodetype, NodeFilter) then
								local nodelevel = 0
								if string.find(val.nodetype, "Elite") or string.find(val.nodetype, "4") then
									nodelevel = 4
								elseif string.find(val.nodetype, "3") then
									nodelevel = 3
								elseif string.find(val.nodetype, "2") then
									nodelevel = 2
								elseif string.find(val.nodetype, "1") then
									nodelevel = 1
								end
								if nodelevel >= NodeLevelFilter then
									HousingLib.NeighborInviteAccept()
									ChatSystemLib.PostOnChannel(2,"Invite from " .. strName .. " accepted by WillYouBeMyNeighbor")
									return
								end
							elseif val.nodetype ~= nil and val.nodelevel ~= nil and val.nodelevel >= NodeLevelFilter and val.nodetype == NodeFilter then
								HousingLib.NeighborInviteAccept()
								ChatSystemLib.PostOnChannel(2,"Invite from " .. strName .. " accepted by WillYouBeMyNeighbor")
								return
							end
						end
					end
				end
			else
				if type(val) == "table" and type(val.share) ~= "table" and key ~= GameLib:GetPlayerUnit():GetName() and val.share >= ShareFilter then
					if val.remaining ~= nil and val.faction == self.faction and string.find(val.nodetype, NodeFilter) then
						local nodelevel = 0
						if string.find(val.nodetype, "Elite") or string.find(val.nodetype, "4") then
							nodelevel = 4
						elseif string.find(val.nodetype, "3") then
							nodelevel = 3
						elseif string.find(val.nodetype, "2") then
							nodelevel = 2
						elseif string.find(val.nodetype, "1") then
							nodelevel = 1
						end
						if nodelevel >= NodeLevelFilter then
							HousingLib.NeighborInviteAccept()
							ChatSystemLib.PostOnChannel(2,"Invite from " .. strName .. " accepted by WillYouBeMyNeighbor")
							return
						end
					elseif val.nodetype ~= nil and val.nodelevel ~= nil and val.nodelevel >= NodeLevelFilter and val.nodetype == NodeFilter then
						HousingLib.NeighborInviteAccept()
						ChatSystemLib.PostOnChannel(2,"Invite from " .. strName .. " accepted by WillYouBeMyNeighbor")
						return
					end
				end
			end
			HousingLib.NeighborInviteDecline()
			ChatSystemLib.PostOnChannel(2,"Invite from " .. strName .. " declined by WillYouBeMyNeighbor based on filters")
			return
		else
			if AcceptAllSocials == true then
				for _, groupMember in pairs(self.rosters[GuildFilter]) do
					if groupMember.strName == key then
						HousingLib.NeighborInviteAccept()
						ChatSystemLib.PostOnChannel(2,"Invite from " .. strName .. " accepted by WillYouBeMyNeighbor")
						return					
					end
				end			
			end
		
			HousingLib.NeighborInviteDecline()
			ChatSystemLib.PostOnChannel(2,"Invite from " .. strName .. " declined by WillYouBeMyNeighbor based on filters")
		end
	else
		aNeighborList:OnNeighborInviteRecieved(strName)
	end
end


function WillYouBeMyNeighbor:BuildSocialWorld()
    local myUnit = GameLib.GetPlayerUnit()
    if (myUnit) then
    end
    
    for _, tCurrGuild in pairs(GuildLib.GetGuilds()) do
    	tCurrGuild:RequestMembers()
    end 
end

function WillYouBeMyNeighbor:OnWindowManagementReady()
	Event_FireGenericEvent("WindowManagementAdd", {wnd = self.wndMain, strName = "WillYouBeMyNeighbor"})
end

function WillYouBeMyNeighbor:IsNeighbor(name)
    local neighborList=HousingLib.GetNeighborList()
    for i=1,#neighborList do
        if neighborList[i].strCharacterName == name then
            return true
        end
    end
	return false
end

function WillYouBeMyNeighbor:HelperConvertToTime(nDays)
	if nDays == 0 then
		return Apollo.GetString("Neighbors_Online")
	end
	if nDays == nil then
		return ""
	end

	local tTimeInfo = {["name"] = "", ["count"] = nil}

	if nDays >= 365 then -- Years
		tTimeInfo["name"] = Apollo.GetString("CRB_Year")
		tTimeInfo["count"] = math.floor(nDays / 365)
	elseif nDays >= 30 then -- Months
		tTimeInfo["name"] = Apollo.GetString("CRB_Month")
		tTimeInfo["count"] = math.floor(nDays / 30)
	elseif nDays >= 7 then
		tTimeInfo["name"] = Apollo.GetString("CRB_Week")
		tTimeInfo["count"] = math.floor(nDays / 7)
	elseif nDays >= 1 then -- Days
		tTimeInfo["name"] = Apollo.GetString("CRB_Day")
		tTimeInfo["count"] = math.floor(nDays)
	else
		local fHours = nDays * 24
		local nHoursRounded = math.floor(fHours)
		local nMin = math.floor(fHours*60)

		if nHoursRounded > 0 then
			tTimeInfo["name"] = Apollo.GetString("CRB_Hour")
			tTimeInfo["count"] = nHoursRounded
		elseif nMin > 0 then
			tTimeInfo["name"] = Apollo.GetString("CRB_Min")
			tTimeInfo["count"] = nMin
		else
			tTimeInfo["name"] = Apollo.GetString("CRB_Min")
			tTimeInfo["count"] = 1
		end
	end

	return String_GetWeaselString(Apollo.GetString("CRB_TimeOffline"), tTimeInfo)
end

----------------------------------------------
-- WillYouBeMyNeighbor Form Functions
-----------------------------------------------------------------------------------------------
-- when the OK button is clicked
function WillYouBeMyNeighbor:OnVisit()
    local neighborList=HousingLib.GetNeighborList()
    for i=1, #neighborList do
        if neighborList[i].strCharacterName == self.currentNeighborName then
			self.currentNeighbor = i
			break
        end
    end	    
	if self.currentNeighbor > #neighborList then
        self.currentNeighbor = 1
		self.currentNeighborName = neighborList[self.currentNeighbor].strCharacterName
        self:UpdateTargetPlot(neighborList[self.currentNeighbor].strCharacterName, self)
    else
        HousingLib.VisitNeighborResidence(neighborList[self.currentNeighbor].nId)
        self.currentNeighbor = self.currentNeighbor + 1
        if self.currentNeighbor > #neighborList then
            self.currentNeighbor = 1
        end
		self.currentNeighborName = neighborList[self.currentNeighbor].strCharacterName
        self:UpdateTargetPlot(neighborList[self.currentNeighbor].strCharacterName, self)
    end
    if neighborList[self.currentNeighbor].fLastOnline == 0 then
        self.wndMain:FindChild("WillYouBeMyNeighborName"):SetTextColor(kcrOnline)
    else
        self.wndMain:FindChild("WillYouBeMyNeighborName"):SetTextColor(kcrOffline)
    end
end

-- when the Cancel button is clicked
function WillYouBeMyNeighbor:OnSkip()
    local neighborList=HousingLib.GetNeighborList()
    self.currentNeighbor = self.currentNeighbor + 1
    if self.currentNeighbor > #neighborList then
        self.currentNeighbor = 1
    end
	self.currentNeighborName = neighborList[self.currentNeighbor].strCharacterName
    self:UpdateTargetPlot(neighborList[self.currentNeighbor].strCharacterName, self)
    if neighborList[self.currentNeighbor].fLastOnline == 0 then
        self.wndMain:FindChild("WillYouBeMyNeighborName"):SetTextColor(kcrOnline)
    else
        self.wndMain:FindChild("WillYouBeMyNeighborName"):SetTextColor(kcrOffline)
    end
end

function WillYouBeMyNeighbor:ServerTime()
	local timetable = GameLib:GetServerTime()
	timetable.year = timetable.nYear
	timetable.month = timetable.nMonth
	timetable.day = timetable.nDay
	timetable.hour = timetable.nHour
	timetable.min = timetable.nMinute
	timetable.sec = timetable.nSecond
	timetable.isdst = false
	return os.time(timetable)
end

function WillYouBeMyNeighbor:SetLocaleData()
	-- Figure out the locale
	local strCancel = Apollo.GetString(1)
	if strCancel == "Abbrechen" then -- German
		Plugs = self.tLocale.de.Plugs
	else
		Plugs = self.tLocale.en.Plugs
	end
end


---------------------------------------------------------------------------------------------------
-- WillYouBeMyNeighborForm Functions
---------------------------------------------------------------------------------------------------

function WillYouBeMyNeighbor:OnClose( wndHandler, wndControl, eMouseButton )
    self.wndMain:Close()
end

function WillYouBeMyNeighbor:OnSlide( wndHandler, wndControl, eMouseButton )
    local x1,y1,x2,y2 = self.wndMain:GetAnchorOffsets()
    if self.expanded == false then
        self.wndMain:SetAnchorOffsets(x1,y1,x1+750,y1+540)
        self.expanded = true
        self.wndMain:FindChild("SlideButton"):ChangeArt("BK3:btnHolo_ExpandCollapse_Inverted")
        self.wndMain:FindChild("Expanded"):Show(true)
		self.wndMain:FindChild("Data"):Show(true)
		self:BuildSocialWorld()
		self:GridRefresh()
    else
        self.wndMain:SetAnchorOffsets(x1,y1,x1+450,y1+170)
        self.expanded = false
        self.wndMain:FindChild("SlideButton"):ChangeArt("BK3:btnHolo_ExpandCollapse")
        self.wndMain:FindChild("Expanded"):Show(false)
		self.wndMain:FindChild("Data"):Show(false)
    end
	local OptInterface = Apollo.GetAddon("OptionsInterface")
	OptInterface:UpdateTrackedWindow(self.wndMain)
end

function WillYouBeMyNeighbor:OnAutoInvite( wndHandler, wndControl, eMouseButton )
    local groupName = self.wndMain:FindChild("ComboCircleList"):GetText()
	if self.rosters == nil then
		self:BuildSocialWorld()
		ChatSystemLib.PostOnChannel(2,"Roster list was not ready, please try again in a few seconds")
		return
	end
    local neighborList=HousingLib.GetNeighborList()
    for key, val in pairs(self.rosters[groupName]) do																			
		local neighbor = false
	    for i=1, #neighborList do
	        if neighborList[i].strCharacterName == val.strName then
				neighbor = true
				break
	        end
	    end
		if neighbor == false and val.fLastOnline == 0 and val.strName ~= GameLib.GetPlayerUnit():GetName() then
			HousingLib.NeighborInviteByName(val.strName)
		end
	end
    ChatSystemLib.PostOnChannel(2,"Neighbor invites sent to online members of " .. groupName)
end

function WillYouBeMyNeighbor:OnSetRatio( wndHandler, wndControl, eMouseButton )
    if HousingLib:IsHousingWorld() == false or HousingLib:IsResidenceOwner() == false then
        ChatSystemLib.PostOnChannel(2,"You must be on your plot to set share ratio")
        return
    end
    local selectedRatio = self.wndMain:FindChild("ComboShareRatioList"):GetText()
    if selectedRatio == "100% to me" then HousingLib.SetNeighborHarvestSplit(0) end
    if selectedRatio == "75% to me" then HousingLib.SetNeighborHarvestSplit(1) end
    if selectedRatio == "50% to me" then HousingLib.SetNeighborHarvestSplit(2) end
    if selectedRatio == "25% to me" then HousingLib.SetNeighborHarvestSplit(3) end
    if selectedRatio == "0% to me" then HousingLib.SetNeighborHarvestSplit(4) end
    ChatSystemLib.PostOnChannel(2,"House share ratio set to " .. selectedRatio)
end

function WillYouBeMyNeighbor:AutoDisplayCheck( wndHandler, wndControl, eMouseButton )
    AutoDisplay = self.wndMain:FindChild("AutoDisplay"):IsChecked()
end



function WillYouBeMyNeighbor:OnRemove( wndHandler, wndControl, eMouseButton )
    local neighborList=HousingLib.GetNeighborList()
	local name = self.wndMain:FindChild("WillYouBeMyNeighborName"):GetText()
    for i=1, #neighborList do
        if neighborList[i].strCharacterName == name then
			HousingLib.NeighborEvict(neighborList[i].nId)
			break
        end
    end
    self.currentNeighbor = self.currentNeighbor + 1
    if self.currentNeighbor > #neighborList then
        self.currentNeighbor = 1
    end
	self.currentNeighborName = neighborList[self.currentNeighbor].strCharacterName
    self:UpdateTargetPlot(neighborList[self.currentNeighbor].strCharacterName, self)
    if neighborList[self.currentNeighbor].fLastOnline == 0 then
        self.wndMain:FindChild("WillYouBeMyNeighborName"):SetTextColor(kcrOnline)
    else
        self.wndMain:FindChild("WillYouBeMyNeighborName"):SetTextColor(kcrOffline)
    end	
end


function WillYouBeMyNeighbor:AutoAcceptCheck( wndHandler, wndControl, eMouseButton )
    AutoAccept = self.wndMain:FindChild("AutoAccept"):IsChecked()
end

function WillYouBeMyNeighbor:OnPrevious( wndHandler, wndControl, eMouseButton )
    local neighborList=HousingLib.GetNeighborList()
    self.currentNeighbor = self.currentNeighbor - 1
    if self.currentNeighbor < 1 then
        self.currentNeighbor = #neighborList
    end
	self.currentNeighborName = neighborList[self.currentNeighbor].strCharacterName
    self:UpdateTargetPlot(neighborList[self.currentNeighbor].strCharacterName, self)
    if neighborList[self.currentNeighbor].fLastOnline == 0 then
        self.wndMain:FindChild("WillYouBeMyNeighborName"):SetTextColor(kcrOnline)
    else
        self.wndMain:FindChild("WillYouBeMyNeighborName"):SetTextColor(kcrOffline)
    end
end

function WillYouBeMyNeighbor:OnHome( wndHandler, wndControl, eMouseButton )
	HousingLib.RequestTakeMeHome()
end

function WillYouBeMyNeighbor:Test( wndHandler, wndControl, eMouseButton )

end

function WillYouBeMyNeighbor:OnRadioRelic( wndHandler, wndControl, eMouseButton )
	NodeFilter = "Relic Excavation"
	self:GridRefresh()
end

function WillYouBeMyNeighbor:OnRadioThicket( wndHandler, wndControl, eMouseButton )
	NodeFilter = "Thicket"
	self:GridRefresh()
end

function WillYouBeMyNeighbor:OnRadioMineral( wndHandler, wndControl, eMouseButton )
	NodeFilter = "Mineral Deposit"
	self:GridRefresh()
end

function WillYouBeMyNeighbor:GridRefresh()
	local grid = self.wndMain:FindChild("Grid")
	grid:DeleteAll()
    for key, val in pairs(RegisteredUsers) do
		if self:IsNeighbor(key) == false then
			if GuildFilter ~= nil and GuildFilter ~= "" and self.rosters[GuildFilter] ~= nil and OnlineUsers[key] ~= nil and OnlineUsers[key] > (self.ServerTime() - 11) then
				for _, groupMember in pairs(self.rosters[GuildFilter]) do
					if groupMember.strName == key then
						if type(val) == "table" and type(val.share) ~= "table" and key ~= GameLib:GetPlayerUnit():GetName() and val.share >= ShareFilter then
							if val.remaining ~= nil and val.faction == self.faction and string.find(val.nodetype, NodeFilter) then
								local nodelevel = 0
								if string.find(val.nodetype, "Elite") or string.find(val.nodetype, "4") then
									nodelevel = 4
								elseif string.find(val.nodetype, "3") then
									nodelevel = 3
								elseif string.find(val.nodetype, "2") then
									nodelevel = 2
								elseif string.find(val.nodetype, "1") then
									nodelevel = 1
								end
								if nodelevel >= NodeLevelFilter then
									local iNewRow = grid:AddRow("")
									grid:SetCellText(iNewRow, 1, key)
									grid:SetCellText(iNewRow, 2, string.format("%s to Owner", shares[val.share + 1]))
									grid:SetCellText(iNewRow, 3, "Level " .. nodelevel)
								end
							elseif val.nodetype ~= nil and val.nodelevel ~= nil and val.nodelevel >= NodeLevelFilter and val.nodetype == NodeFilter then
								local iNewRow = grid:AddRow("")
								grid:SetCellText(iNewRow, 1, key)
								grid:SetCellText(iNewRow, 2, string.format("%s to Owner", shares[val.share + 1]))
								grid:SetCellText(iNewRow, 3, "Level " .. val.nodelevel)
							end
						end
					end
				end
			else
				if type(val) == "table" and type(val.share) ~= "table" and key ~= GameLib:GetPlayerUnit():GetName() and val.share >= ShareFilter and OnlineUsers[key] ~= nil and OnlineUsers[key] > (self.ServerTime() - 11) then
					if val.remaining ~= nil and val.faction == self.faction and string.find(val.nodetype, NodeFilter) then
						local nodelevel = 0
						if string.find(val.nodetype, "Elite") or string.find(val.nodetype, "4") then
							nodelevel = 4
						elseif string.find(val.nodetype, "3") then
							nodelevel = 3
						elseif string.find(val.nodetype, "2") then
							nodelevel = 2
						elseif string.find(val.nodetype, "1") then
							nodelevel = 1
						end
						if nodelevel >= NodeLevelFilter then
							local iNewRow = grid:AddRow("")
							grid:SetCellText(iNewRow, 1, key)
							grid:SetCellText(iNewRow, 2, string.format("%s to Owner", shares[val.share + 1]))
							grid:SetCellText(iNewRow, 3, "Level " .. nodelevel)
						end
					elseif val.nodetype ~= nil and val.nodelevel ~= nil and val.nodelevel >= NodeLevelFilter and val.nodetype == NodeFilter then
						local iNewRow = grid:AddRow("")
						grid:SetCellText(iNewRow, 1, key)
						grid:SetCellText(iNewRow, 2, string.format("%s to Owner", shares[val.share + 1]))
						grid:SetCellText(iNewRow, 3, "Level " .. val.nodelevel)
					end
				end
			end
		end
	end
end

function WillYouBeMyNeighbor:OnAddNeighbors( wndHandler, wndControl, eMouseButton )
    for key, val in pairs(RegisteredUsers) do
		if self:IsNeighbor(key) == false	then
			if GuildFilter ~= nil and GuildFilter ~= "" and self.rosters[GuildFilter] ~= nil and OnlineUsers[key] ~= nil and OnlineUsers[key] > (self.ServerTime() - 11) then
				for _, groupMember in pairs(self.rosters[GuildFilter]) do
					if groupMember.strName == key then
						if type(val) == "table" and type(val.share) ~= "table" and key ~= GameLib:GetPlayerUnit():GetName() and val.share >= ShareFilter then
							if val.remaining ~= nil and val.faction == self.faction and string.find(val.nodetype, NodeFilter) then
								local nodelevel = 0
								if string.find(val.nodetype, "Elite") or string.find(val.nodetype, "4") then
									nodelevel = 4
								elseif string.find(val.nodetype, "3") then
									nodelevel = 3
								elseif string.find(val.nodetype, "2") then
									nodelevel = 2
								elseif string.find(val.nodetype, "1") then
									nodelevel = 1
								end
								if nodelevel >= NodeLevelFilter then
								    HousingLib.NeighborInviteByName(key)
								end
							elseif val.nodetype ~= nil and val.nodelevel ~= nil and val.nodelevel >= NodeLevelFilter and val.nodetype == NodeFilter then
						        HousingLib.NeighborInviteByName(key)
							end
						end
					end
				end
			else
				if type(val) == "table" and type(val.share) ~= "table" and key ~= GameLib:GetPlayerUnit():GetName() and val.share >= ShareFilter and OnlineUsers[key] ~= nil and OnlineUsers[key] > (self.ServerTime() - 11) then
					if val.remaining ~= nil and val.faction == self.faction and string.find(val.nodetype, NodeFilter) then
						local nodelevel = 0
						if string.find(val.nodetype, "Elite") or string.find(val.nodetype, "4") then
							nodelevel = 4
						elseif string.find(val.nodetype, "3") then
							nodelevel = 3
						elseif string.find(val.nodetype, "2") then
							nodelevel = 2
						elseif string.find(val.nodetype, "1") then
							nodelevel = 1
						end
						if nodelevel >= NodeLevelFilter then
						    HousingLib.NeighborInviteByName(key)
						end
					elseif val.nodetype ~= nil and val.nodelevel ~= nil and val.nodelevel >= NodeLevelFilter and val.nodetype == NodeFilter then
				        HousingLib.NeighborInviteByName(key)
					end
				end
			end
		end
	end	
    ChatSystemLib.PostOnChannel(2,"Neighbor invites sent")
end

function WillYouBeMyNeighbor:OnRadio100( wndHandler, wndControl, eMouseButton )
	ShareFilter = 0
	self:GridRefresh()
end

function WillYouBeMyNeighbor:OnRadio75( wndHandler, wndControl, eMouseButton )
	ShareFilter = 1
	self:GridRefresh()
end

function WillYouBeMyNeighbor:OnRadio50( wndHandler, wndControl, eMouseButton )
	ShareFilter = 2
	self:GridRefresh()
end

function WillYouBeMyNeighbor:OnRadio25( wndHandler, wndControl, eMouseButton )
	ShareFilter = 3
	self:GridRefresh()
end

function WillYouBeMyNeighbor:OnRadio0( wndHandler, wndControl, eMouseButton )
	ShareFilter = 4
	self:GridRefresh()
end

function WillYouBeMyNeighbor:OnLevel1( wndHandler, wndControl, eMouseButton )
	NodeLevelFilter = 1
	self:GridRefresh()
end

function WillYouBeMyNeighbor:OnLevel2( wndHandler, wndControl, eMouseButton )
	NodeLevelFilter = 2
	self:GridRefresh()
end

function WillYouBeMyNeighbor:OnLevel3( wndHandler, wndControl, eMouseButton )
	NodeLevelFilter = 3
	self:GridRefresh()
end

function WillYouBeMyNeighbor:OnLevel4( wndHandler, wndControl, eMouseButton )
	NodeLevelFilter = 4
	self:GridRefresh()
end

function WillYouBeMyNeighbor:OnGuildFilterChange( wndHandler, wndControl )
	GuildFilter = wndControl:GetSelectedText()
	self:GridRefresh()
end

function WillYouBeMyNeighbor:DeclineByFilter( wndHandler, wndControl, eMouseButton )
	DeclineByFilter = wndControl:IsChecked()
end


function WillYouBeMyNeighbor:OnFilterPlantPirates( wndHandler, wndControl, eMouseButton )
	PlantPiratesAlert = wndControl:IsChecked()
end

function WillYouBeMyNeighbor:OnHarvestNotifications( wndHandler, wndControl, eMouseButton )
	HarvestNotifications = wndControl:IsChecked()
end

function WillYouBeMyNeighbor:OnAcceptAllSocials( wndHandler, wndControl, eMouseButton )
	AcceptAllSocials = wndControl:IsChecked()
end

-----------------------------------------------------------------------------------------------
-- WillYouBeMyNeighbor Instance
-----------------------------------------------------------------------------------------------
local WillYouBeMyNeighborInst = WillYouBeMyNeighbor:new()
WillYouBeMyNeighborInst:Init()